#### NSE BhavCopy Download

Download daily Bhavcopy stock data from NSE webstite.

Installtion steps:

PyPI:

pip install stocksdata

Git:

python -m pip install -e git+https://github.com/KiranNanduri/StockCode.git
